# GitLab Delete Issue

install from pip
```
pip install gitlab-issue-delete
```

delete all issue from gitlab project.

usage
```
$ gitlab-issue-delete
```

and follow the instruction

you need `gitlab` and `accesstoken` 

default config file found at

```
$HOME/.config/gitlab/config
```